function  curvas_hidrostaticas(fichero,op,ksec)

% Esta funcin realiza clculos hidrostticos a partir
% del conocimiento de la posicin de las secciones, y
% de las semimangas para diferentes calados
% Los clculos hidrostticos que realiza son:
% Aw  rea de flotacin para cada lnea de agua
% Mx  Momento de rea del plano del agua
% Xf  Centro de flotacin
% It  Momento de inercia transversal
% Iy  Momento de inercia del plano de agua
% IL  Momento de inercia longitudinal
% TPC Toneladas por centimetro de inmersin
% V   Volumen de desplazamiento o de carena
% MB  Momento de desplazamiento del volumen
% ZB  Centro vertical de carena
% BMt Radio metacntrico transversal
% BMl Radio metacntrico longitudinal
% As  rea de las secciones
% MBx Momento respecto de la seccin (sin curva)
% XB  Centro longitudinal de carena  (sin curva)
%
% curvas_hidrostaticas(fichero,op,ksec)
% fichero es el nombre del archivo excel que contiene las lineas de agua
% op indica si quiere grfica de los distintos elementos o no
%    op='ssssssssssssn' indica que se quieren todas las grficas menos la
%    de As
%    Notar que se trata de 13 curvas hidrstaticos distintos
% ksec nmero de seccin del cual se quiere saber el rea


% Leemos el fichero con la posicin de las secciones, y
% las semimangas para cada altura z

a=xlsread(['./Lneas de Agua/',fichero]);
[n,m]=size(a);

% secciones
x=a(1,2:m);    % tamao 1 x m-1

% alturas
z=a(2:n,1);    % tamao n-1 x 1

% semimangas
y=a(2:n,2:m);  % tamao n-1 x m-1


% Densidad del aguas en el oceano en el Sistema Internacional
pw = 1.025;    % en ton/m^3
 

% Realiza el clculo de los parmetros hidrostticos de cada uno de los calados

for k=1:n-1

    y_linea=y(k,1:m-1);
    Aw(k)=2*trapecios(x,y_linea);          % rea de flotacin de cada lnea de agua
    Mx(k) = 2*trapecios(x,x.*y_linea);      % Momento de rea del plano del agua
    Xf(k) = Mx(k)/Aw(k);                    % Centro de flotacin
    It(k) = 2/3*trapecios(x,y_linea.^3);    % Momento transversal de inercia
    Iy(k) = 2*trapecios(x,(x.^2).*y_linea); % Momento de inercia del plano de agua
    IL(k) = Iy(k)+ Xf(k)^2* Aw(k);          % Momento longitudinal de inercia
    TCI (k) = Aw(k)*pw/100;                 % Toneladas por centimetro de inmersin
end


for k=1:n-1
    V(k)=trapecios(z(k:n-1)',Aw(k:n-1));   % Volumen de desplazamiento para cada calado
    D(k)=pw*V(k);                          % Desplazamiento para cada calado
    MB(k)=trapecios(z(k:n-1)',z(k:n-1)'.*Aw(k:n-1));  % Momento de desplazamiento respecto de z
    KB(k)=MB(k)/V(k);                       % Coordenada z del centro de carena
    BMt(k)=It(k)/V(k);                      % Radio metacntrico transversal
    BMl(k)=IL(k)/V(k);                      % Radio metacntrico longitudinal
end

% Realiza el clculo de los parmetros hidrostticos de cada una de las secciones
% para cada calado


for k=1:n-1
    for i=1:m-1
        y_linea=y(k:n-1,i)';
        As(k,i)=2*trapecios(z(k:n-1)',y_linea);          % rea de cada seccin
    end

    MBx(k)=trapecios(x,x.*As(k,:));                     % Momento respecto de la seccin
    XB(k)=MBx(k)/V(k);                                % Centro Longitudinal de la carena

end



for k=1:n-1
    ind=find(y(k,1:m-1)~=0);
    xmin(k)=x(ind(1));                             % Mnimo valor de x a cada calado
    xMax(k)=x(ind(length(ind)));                   % Mximo valor de x a cada calado
    Eslora(k)=xMax(k)-xmin(k);                     % Eslora correspondiente a cada calado
    Manga_maxima(k)=2*max(y(k,1:m-1));             % Manga mxima a cada calado
    MTC(k)=D(k)*BMl(k)/(100*Eslora(k));            % Momento para alterar el trimado 1 cm
    Cb(k)=V(k)/Eslora(k)/Manga_maxima(k)/z(k);     % Coeficiente de bloque
    Seccion_maxima(k)=max(As(k,:));
    Cm(k)=Seccion_maxima(k)/Manga_maxima(k)/z(k);  % Coeficiente de la maestra
    Cf(k)=Aw(k)/Eslora(k)/Manga_maxima(k);         % Coeficiente de Flotacin
    Cpv(k)=Cb(k)/Cf(k);                            % Coeficiente prismtico vertical
    Cph(k)=Cb(k)/Cm(k);                            % Coeficiente prismtico horizontal
end



% Dibujamos el rea de flotacin

if op(1)=='s'

    h1=figure('Name',[blanks(6),'rea de flotacin'],'Position',[100 100 1000 600]);

    plot(Aw,z,'b','LineW',2)

    grid on
    box on
    set(gca,'FontW','Bold')
    xlabel('rea de Flotacin','FontW','Bold')
    ylabel('Calado ','FontW','Bold')

    % Centramos y escalamos
    set( h1,'Units', 'pixels' );
    screenSize = get(0, 'ScreenSize');
    position = get( h1,'Position');
    position(1) = (screenSize(3)-position(3))/2;
    position(2) = (screenSize(4)-position(4))/2;
    set( h1,'Position', position );


end

% Dibujamos el Momento de rea del plano del agua

if op(2)=='s'

    h2=figure('Name',[blanks(6),'Momento de rea del plano del agua'],'Position',[100 100 1000 600]);

    plot(Mx,z,'b','LineW',2)

    grid on
    box on
    set(gca,'FontW','Bold')
    xlabel('Momento de rea del plano del agua','FontW','Bold')
    ylabel('Calado ','FontW','Bold')

    % Centramos y escalamos
    set( h2,'Units', 'pixels' );
    screenSize = get(0, 'ScreenSize');
    position = get( h2,'Position');
    position(1) = (screenSize(3)-position(3))/2;
    position(2) = (screenSize(4)-position(4))/2;
    set( h2,'Position', position );

end

% Dibujamos el Centro de flotacin

if op(3)=='s'

    h3=figure('Name',[blanks(6),'Centro de flotacin'],'Position',[100 100 1000 600]);

    plot(Xf,z,'b','LineW',2)

    grid on
    box on
    set(gca,'FontW','Bold')
    xlabel('Centro de flotacin','FontW','Bold')
    ylabel('Calado ','FontW','Bold')

    % Centramos y escalamos
    set( h3,'Units', 'pixels' );
    screenSize = get(0, 'ScreenSize');
    position = get( h3,'Position');
    position(1) = (screenSize(3)-position(3))/2;
    position(2) = (screenSize(4)-position(4))/2;
    set( h3,'Position', position );


end


% Dibujamos el Momento transversal de inercia

if op(4)=='s'

    h4=figure('Name',[blanks(6),'Momento transversal de inercia'],'Position',[100 100 1000 600]);

    plot(It,z,'b','LineW',2)

    grid on
    box on
    set(gca,'FontW','Bold')
    xlabel('Momento transversal de inercia','FontW','Bold')
    ylabel('Calado ','FontW','Bold')

    % Centramos y escalamos
    set( h4,'Units', 'pixels' );
    screenSize = get(0, 'ScreenSize');
    position = get( h4,'Position');
    position(1) = (screenSize(3)-position(3))/2;
    position(2) = (screenSize(4)-position(4))/2;
    set( h4,'Position', position );


end


% Dibujamos el Momento de inercia del plano de agua

if op(5)=='s'

    h5=figure('Name',[blanks(6),'Momento de inercia del plano de agua'],'Position',[100 100 1000 600]);

    plot(Iy,z,'b','LineW',2)

    grid on
    box on
    set(gca,'FontW','Bold')
    xlabel('Momento de inercia del plano de agua','FontW','Bold')
    ylabel('Calado ','FontW','Bold')

    % Centramos y escalamos
    set( h5,'Units', 'pixels' );
    screenSize = get(0, 'ScreenSize');
    position = get( h5,'Position');
    position(1) = (screenSize(3)-position(3))/2;
    position(2) = (screenSize(4)-position(4))/2;
    set( h5,'Position', position );

end


% Dibujamos el Momento longitudinal de inercia

if op(6)=='s'

    h6=figure('Name',[blanks(6),'Momento longitudinal de inercia'],'Position',[100 100 1000 600]);

    plot(IL,z,'b','LineW',2)

    grid on
    box on
    set(gca,'FontW','Bold')
    xlabel('Momento longitudinal de inercia','FontW','Bold')
    ylabel('Calado ','FontW','Bold')

    % Centramos y escalamos
    set( h6,'Units', 'pixels' );
    screenSize = get(0, 'ScreenSize');
    position = get( h6,'Position');
    position(1) = (screenSize(3)-position(3))/2;
    position(2) = (screenSize(4)-position(4))/2;
    set( h6,'Position', position );

end

% Dibujamos el Toneladas por centimetro de inmersin

if op(7)=='s'

    h7=figure('Name',[blanks(6),'Toneladas por centimetro de inmersin'],'Position',[100 100 1000 600]);

    plot(TCI,z,'b','LineW',2)

    grid on
    box on
    set(gca,'FontW','Bold')
    xlabel('Toneladas por centimetro de inmersin','FontW','Bold')
    ylabel('Calado ','FontW','Bold')

    % Centramos y escalamos
    set( h7,'Units', 'pixels' );
    screenSize = get(0, 'ScreenSize');
    position = get( h7,'Position');
    position(1) = (screenSize(3)-position(3))/2;
    position(2) = (screenSize(4)-position(4))/2;
    set( h7,'Position', position );

end

% Dibujamos el Volumen de desplazamiento

if op(8)=='s'

    h8=figure('Name',[blanks(6),'Volumen de desplazamiento'],'Position',[100 100 1000 600]);

    plot(V,z,'b','LineW',2)

    grid on
    box on
    set(gca,'FontW','Bold')
    xlabel('Volumen de desplazamiento','FontW','Bold')
    ylabel('Calado ','FontW','Bold')

    % Centramos y escalamos
    set( h8,'Units', 'pixels' );
    screenSize = get(0, 'ScreenSize');
    position = get( h8,'Position');
    position(1) = (screenSize(3)-position(3))/2;
    position(2) = (screenSize(4)-position(4))/2;
    set( h8,'Position', position );

end

% Dibujamos el Momento de desplazamiento respecto de z

if op(9)=='s'

    h9=figure('Name',[blanks(6),'Momento de desplazamiento respecto de z'],'Position',[100 100 1000 600]);

    plot(MB,z,'b','LineW',2)

    grid on
    box on
    set(gca,'FontW','Bold')
    xlabel('Momento de desplazamiento respecto de z','FontW','Bold')
    ylabel('Calado ','FontW','Bold')

    % Centramos y escalamos
    set( h9,'Units', 'pixels' );
    screenSize = get(0, 'ScreenSize');
    position = get( h9,'Position');
    position(1) = (screenSize(3)-position(3))/2;
    position(2) = (screenSize(4)-position(4))/2;
    set( h9,'Position', position );

end

% Dibujamos el Coordenada z del centro de carena

if op(10)=='s'

    h10=figure('Name',[blanks(6),'Coordenada z del centro de carena'],'Position',[100 100 1000 600]);

    plot(KB,z,'b','LineW',2)

    grid on
    box on
    set(gca,'FontW','Bold')
    xlabel('Coordenada z del centro de carena','FontW','Bold')
    ylabel('Calado ','FontW','Bold')

    % Centramos y escalamos
    set( h10,'Units', 'pixels' );
    screenSize = get(0, 'ScreenSize');
    position = get( h10,'Position');
    position(1) = (screenSize(3)-position(3))/2;
    position(2) = (screenSize(4)-position(4))/2;
    set( h10,'Position', position );

end


% Dibujamos el Radio metacntrico transversal

if op(11)=='s'

    h11=figure('Name',[blanks(6),'Radio metacntrico transversal'],'Position',[100 100 1000 600]);

    plot(BMt,z,'b','LineW',2)

    grid on
    box on
    set(gca,'FontW','Bold')
    xlabel('Radio metacntrico transversal','FontW','Bold')
    ylabel('Calado ','FontW','Bold')

    % Centramos y escalamos
    set( h11,'Units', 'pixels' );
    screenSize = get(0, 'ScreenSize');
    position = get( h11,'Position');
    position(1) = (screenSize(3)-position(3))/2;
    position(2) = (screenSize(4)-position(4))/2;
    set( h11,'Position', position );

end

% Dibujamos el Radio metacntrico longitudinal

if op(12)=='s'

    h12=figure('Name',[blanks(6),'Radio metacntrico longitudinal'],'Position',[100 100 1000 600]);

    plot(BMl,z,'b','LineW',2)

    grid on
    box on
    set(gca,'FontW','Bold')
    xlabel('Radio metacntrico longitudinal','FontW','Bold')
    ylabel('Calado ','FontW','Bold')

    % Centramos y escalamos
    set( h12,'Units', 'pixels' );
    screenSize = get(0, 'ScreenSize');
    position = get( h12,'Position');
    position(1) = (screenSize(3)-position(3))/2;
    position(2) = (screenSize(4)-position(4))/2;
    set( h12,'Position', position );

end

% Dibujamos el rea de las Secciones

if op(13)=='s'

    h=figure('Name',[blanks(6),'rea de las secciones'],'Position',[100 100 1000 600]);
    plot(x,As,'b','LineW',2)

    grid on
    box on
    set(gca,'FontW','Bold')
    xlabel('Secciones','FontW','Bold')
    ylabel('rea de las Secciones','FontW','Bold')

    % Centramos y escalamos
    set( h,'Units', 'pixels' );
    screenSize = get(0, 'ScreenSize');
    position = get( h,'Position');
    position(1) = (screenSize(3)-position(3))/2;
    position(2) = (screenSize(4)-position(4))/2;
    set( h,'Position', position );

end

% Dibujamos el Coordenada z del centro de carena

if op(14)=='s'

    h10=figure('Name',[blanks(6),'Coordenada x del centro de carena'],'Position',[100 100 1000 600]);

    plot(XB,z,'b','LineW',2)

    grid on
    box on
    set(gca,'FontW','Bold')
    xlabel('Coordenada x del centro de carena','FontW','Bold')
    ylabel('Calado ','FontW','Bold')

    % Centramos y escalamos
    set( h10,'Units', 'pixels' );
    screenSize = get(0, 'ScreenSize');
    position = get( h10,'Position');
    position(1) = (screenSize(3)-position(3))/2;
    position(2) = (screenSize(4)-position(4))/2;
    set( h10,'Position', position );

end



% Mandamos los datos a una figura en la pantalla
g=figure('Tag','datos','Name',[blanks(6),'Datos de salida'],'Position',[100 100 1000 600]);
axis off

% Definimos una cadena de carcteres que contiene los datos de salida
str={['Calado',blanks(2),num2str(z(1)),blanks(2),'m'],...
    ['rea de flotacin (Aw):',blanks(2),num2str(Aw(1)),blanks(2),'m^2'],...
    ['Momento de rea del plano del agua (Mx):',blanks(2),num2str(Mx(1)),blanks(2),'m^3'],...
    ['Centro de flotacin (Xf):',blanks(2),num2str(Xf(1)),blanks(2),'m'],...
    ['Momento de inercia transversal (It):',blanks(2),num2str(It(1)),blanks(2),'m^4'],...
    ['Radio metacntrico transversal (BMt):',blanks(2),num2str(BMt(1)),blanks(2),'m'],...
    ['Momento de inercia del plano de agua (Iy):',blanks(2),num2str(Iy(1)),blanks(2),'m^4'],...
    ['Momento de inercia longitudinal (IL):',blanks(2),num2str(IL(1)),blanks(2),'m^4'],...
    ['Radio metacntrico longitudinal (BMl):',blanks(2),num2str(BMl(1)),blanks(2),'m'],...
    ['Volumen de carena (V):',blanks(2),num2str(V(1)),blanks(2),'m^3'],...
    ['Desplazamiento (D):',blanks(2),num2str(D(1)),blanks(2),blanks(2),'ton'],...
    ['Momento de desplazamiento (MB):',blanks(2),num2str(MB(1)),blanks(2),'m^3'],...
    ['Centro vertical de carena (KB):',blanks(2),num2str(KB(1)),blanks(2),'m'],...
    ['Toneladas por centmetro de inmersin (TCI):',blanks(2),num2str(TCI(1)),blanks(2),'ton/cm'],...
    ['Centro longitudinal de carena (XB):',blanks(2),num2str(XB(1)),blanks(2),'m'],...
    ['Momento para alterar el trimado 1 cm (MTC):',blanks(2),num2str(MTC(1)),blanks(2),'ton*m'],...
    ['rea de la seccin (As) ',num2str(ksec),':',blanks(2),num2str(As(1,ksec)),blanks(2),'m^2'],...
    ['Coeficiente de bloque(Cb):',blanks(2),num2str(Cb(1))],...
    ['Coeficiente de la maestra(Cm):',blanks(2),num2str(Cm(1))],...
    ['Coeficiente de flotacin(Cf):',blanks(2),num2str(Cf(1))],...
    ['Coeficiente prismtico horizontal(Cph):',blanks(2),num2str(Cph(1))],...
    ['Coeficiente prismtico vertical(Cpv):',blanks(2),num2str(Cpv(1))]};

g1=uicontrol('Style','Text','String',str,'FontSize',16,'FontWeight','bold','Units','normalized',...
    'Position',[0 0 1 0.95],'Background','White','HorizontalAlignment','left');

g2=uicontrol('Style','Text','String', {'Valores Hidrostticos'}, 'FontSize',18,'FontWeight','bold',...
    'Units','normalized','Position',[0 0.95 1 0.05],'Background','green','HorizontalAlignment','center','ForegroundColor','blue');

% Centramos y escalamos
set(g,'Units', 'pixels' );
screenSize = get(0, 'ScreenSize');
position = get(g,'Position');
position(1) = (screenSize(3)-position(3))/2;
position(2) = (screenSize(4)-position(4))/2;
set(g,'Position', position );


% Sacamos los datos en forma de tabla a un fichero excel

tabla=[z,Aw',TCI',Xf',V',D',KB',XB',BMt',BMl',MTC',xmin',xMax',Eslora'];
nombre_fichero_xls=['Clculos hidrostticos adrizado_',fichero(1:end-3),'xls'];
delete(nombre_fichero_xls);
rango=['a2:N',num2str(n-1)];
xlswrite(nombre_fichero_xls,tabla,rango);
str_xls={'Calado','Aw','TCI','Xf','V','D','KB','XB','BMt','BMl','MTC','xmin','xMax','Eslora'};
xlswrite(nombre_fichero_xls,str_xls,'A1:N1');
